Download
========

The latest version of Globus Provision is |release| (see :ref:`changelog`)

The recommended way of installing Globus Provision is using ``easy_install``. You can find
instructions on how to do this in both the :ref:`Quickstart Guide <chap_quickstart>` and the 
:ref:`Installation <chap_install>` chapter of the documentation.

If you do need to download Globus Provision as an installable Python Egg or as a source
tarball, both are available for download in the Python Package Index: http://pypi.python.org/pypi/globus-provision

Sample files
============

The sample files shown in the documentation are available for download as a
:docs-tar:`tarball <samples>` or a :docs-zip:`ZIP file <samples>`.

Development version
===================

If you want to use the latest development version of Globus Provision, you can
track our `GitHub repository <https://github.com/globusonline/provision>`_.

The :ref:`Installation <chap_install>` chapter of the documentation provides
instructions on how to check out our code from GitHub.
  